@@ -16,13 +16,14 @@ except ImportError:
     UTC = _timezone.utc
 
 from datetime import datetime
-
 from typing import Literal
 
 import ruamel.yaml
 from git import Repo
 from git.exc import InvalidGitRepositoryError
 
+from calkit.models import ProjectInfo
+
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__package__)
 
@@ -60,8 +61,10 @@ def find_project_dirs(relative=False, max_depth=3) -> list[str]:
 
 
 def load_calkit_info(
-    wdir=None, process_includes: bool | str | list[str] = False
-) -> dict:
+    wdir=None,
+    process_includes: bool | str | list[str] = False,
+    as_pydantic: bool = False,
+) -> dict | ProjectInfo:
     """Load Calkit project information.
 
     Parameters
@@ -99,6 +102,8 @@ def load_calkit_info(
                         with open(include_fpath) as f:
                             include_data = ryaml.load(f)
                         info[kind][obj_name] |= include_data
+    if as_pydantic:
+        return ProjectInfo.model_validate(info)
     return info
 
 
